@@ -25,26 +25,30 @@ void cgit_print_patch(const char *new_rev, const char *old_rev,
 		new_rev = ctx.qry.head;
 
 	if (get_sha1(new_rev, new_rev_sha1)) {
-		cgit_print_error("Bad object id: %s", new_rev);
+		cgit_print_error_page(404, "Not found",
+				"Bad object id: %s", new_rev);
 		return;
 	}
 	commit = lookup_commit_reference(new_rev_sha1);
 	if (!commit) {
-		cgit_print_error("Bad commit reference: %s", new_rev);
+		cgit_print_error_page(404, "Not found",
+				"Bad commit reference: %s", new_rev);
 		return;
 	}
 
 	if (old_rev) {
 		if (get_sha1(old_rev, old_rev_sha1)) {
-			cgit_print_error("Bad object id: %s", old_rev);
+			cgit_print_error_page(404, "Not found",
+					"Bad object id: %s", old_rev);
 			return;
 		}
 		if (!lookup_commit_reference(old_rev_sha1)) {
-			cgit_print_error("Bad commit reference: %s", old_rev);
+			cgit_print_error_page(404, "Not found",
+					"Bad commit reference: %s", old_rev);
 			return;
 		}
 	} else if (commit->parents && commit->parents->item) {
-		hashcpy(old_rev_sha1, commit->parents->item->object.sha1);
+		hashcpy(old_rev_sha1, commit->parents->item->object.oid.hash);
 	} else {
 		hashclr(old_rev_sha1);
 	}
